# Do not generate provides for private libraries
%global __provides_exclude_from ^%{_libdir}/stunnel/.*$

Summary:	Program that wraps normal socket connections with SSL/TLS
Name:		stunnel
Version:	5.75
Release:	%mkrel 1
License:	GPLv2+
Group:		System/Servers
URL:		https://www.stunnel.org/
Source0:	https://www.stunnel.org/downloads/%{name}-%{version}.tar.gz
Source1:	https://www.stunnel.org/downloads/%{name}-%{version}.tar.gz.asc
Source2:	stunnel.service
Source3:	stunnel.tmpfiles
	
# Apply patch stunnel-5.61-systemd-service.patch
Patch1:   stunnel-5.61-systemd-service.patch
# Apply patch stunnel-5.56-system-ciphers.patch
Patch3:   stunnel-5.69-system-ciphers.patch
# Apply patch stunnel-5.72-default-tls-version.patch
Patch5:   stunnel-5.72-default-tls-version.patch
# Apply patch stunnel-5.56-curves-doc-update.patch
Patch6:   stunnel-5.56-curves-doc-update.patch
BuildRequires:	pkgconfig(openssl) >= 0.9.5
Requires(post):	openssl
BuildRequires: netcat-traditional
BuildRequires: python3
BuildRequires: python3-cryptography
BuildRequires: openssl

%description
The stunnel program is designed to work as SSL encryption wrapper between 
remote clients and local (inetd-startable) or remote servers. The concept is 
that having non-SSL aware daemons running on your system you can easily set 
them up to communicate with clients over secure SSL channels.

stunnel can be used to add SSL functionality to commonly used inetd daemons 
like POP-2, POP-3, and IMAP servers, to standalone daemons like NNTP, SMTP 
and HTTP, and in tunneling PPP over network sockets without changes to the 
source code.

%prep
%autosetup -S gendiff -p1

%build
%configure \
    --with-ssl=%{_prefix} \
    --disable-static \
    --enable-shared \
    --with-bashcompdir=%{buildroot}%{_datadir}/bash-completion/completions \
--disable-libwrap \
    --disable-fips \
    --enable-ipv6
    
%make_build pkglibdir=%{_libdir}

%install
# (oe) hack... don't generate the pem file, and stunnel.conf
install -d %{buildroot}%{_sysconfdir}/%{name}
touch %{buildroot}%{_sysconfdir}/%{name}/stunnel.pem

%makeinstall docdir=`pwd`/doc-to-install pkglibdir=%{buildroot}%{_libdir}

install -D -m 644 %{SOURCE2} %{buildroot}%{_unitdir}/stunnel.service

install -D -m 644 %{SOURCE3} %{buildroot}%{_prefix}/lib/tmpfiles.d/stunnel.conf

mv %{buildroot}%{_sysconfdir}/%{name}/stunnel.conf-sample \
    %{buildroot}%{_sysconfdir}/%{name}/stunnel.conf

perl -pi \
    -e 's|chroot = .*|chroot = /run/stunnel|;' \
    -e 's|cert = .*|cert = /etc/pki/tls/certs/stunnel.pem|;' \
    -e 's|;key = .*|key = /etc/pki/tls/private/stunnel.pem|;' \
    -e 's|;pid = .*|pid = /run/stunnel/stunnel.pid|;' \
    -e 's|options = NO_SSLv2|options = NO_SSLv2\noptions = NO_SSLv3|;' \
    %{buildroot}%{_sysconfdir}/%{name}/stunnel.conf

# Move the translated man pages to the right subdirectories, and strip off the
# language suffixes.
for lang in pl ; do
    mkdir -p %{buildroot}%{_mandir}/${lang}/man8
    mv %{buildroot}%{_mandir}/man8/*.${lang}.8* %{buildroot}%{_mandir}/${lang}/man8/
    rename ".${lang}" "" %{buildroot}%{_mandir}/${lang}/man8/*
done

# cleanup
rm -f ./doc-to-install/INSTALL.W32 ./doc-to-install/COPYRIGHT.GPL
rm -f %{buildroot}%{_sysconfdir}/%{name}/stunnel.pem
rm -f %{buildroot}%{_libdir}/libstunnel.la

%check
if ! make test; then
	for i in tests/logs/*.log; do
		echo "$i":
		cat "$i"
	done
	exit 1
fi

%post
%_tmpfilescreate %{name}
%_create_ssl_certificate stunnel

%files
%doc doc-to-install/*
%{_bindir}/stunnel
%{_bindir}/stunnel3
%{_mandir}/man8/stunnel.8.*
%lang(pl) %{_mandir}/pl/man8/stunnel.8*
%config(noreplace) %{_sysconfdir}/%{name}/stunnel.conf
%{_unitdir}/stunnel.service
%{_prefix}/lib/tmpfiles.d/stunnel.conf
%{_libdir}/libstunnel.so
%{_datadir}/bash-completion/completions/%{name}.bash


%changelog
* Mon Jun 02 2025 ns80 <ns80> 5.75-1.mga10
+ Revision: 2187864
- try building without FIPS
- new version 5.75

* Tue Mar 14 2023 luigiwalser <luigiwalser> 5.69-1.mga9
+ Revision: 1948872
- 5.69
- update patches 3 and 5 from fedora

* Sun Dec 25 2022 guillomovitch <guillomovitch> 5.67-1.mga9
+ Revision: 1926885
- sync patch set with Fedora
- fix build dependencies
- drop obsolete libwrapper support
- new version 5.67
+ joequant <joequant>
- update to 5.67

* Sat Mar 19 2022 umeabot <umeabot> 5.63-2.mga9
+ Revision: 1800666
- Mageia 9 Mass Rebuild

* Fri Mar 18 2022 ns80 <ns80> 5.63-1.mga9
+ Revision: 1797978
- new version 5.63 (mga#30185)

* Wed Jan 26 2022 luigiwalser <luigiwalser> 5.62-1.mga9
+ Revision: 1769935
- 5.62

* Fri Oct 01 2021 guillomovitch <guillomovitch> 5.59-2.mga9
+ Revision: 1747297
- rebuild for openssl 3.0.0

* Fri Aug 06 2021 luigiwalser <luigiwalser> 5.59-1.mga9
+ Revision: 1739876
- 5.59

* Fri Jan 22 2021 neoclust <neoclust> 5.57-1.mga8
+ Revision: 1672893
- New version 5.57 ( security release )

* Wed Feb 19 2020 umeabot <umeabot> 5.56-2.mga8
+ Revision: 1543157
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Wed Jan 15 2020 luigiwalser <luigiwalser> 5.56-1.mga8
+ Revision: 1478118
- 5.56

* Sat Oct 12 2019 daviddavid <daviddavid> 5.55-1.mga8
+ Revision: 1452037
- new version: 5.55

* Sun Sep 23 2018 umeabot <umeabot> 5.44-2.mga7
+ Revision: 1301217
- Mageia 7 Mass Rebuild

* Tue Jan 02 2018 guillomovitch <guillomovitch> 5.44-1.mga7
+ Revision: 1189180
- new version

* Sun Sep 03 2017 pterjan <pterjan> 5.42-1.mga7
+ Revision: 1151056
- Update to 5.42 which should fix crashes with new openssl

* Wed Aug 02 2017 guillomovitch <guillomovitch> 5.37-2.mga7
+ Revision: 1133979
- rebuild for latest openssl

* Fri Nov 11 2016 guillomovitch <guillomovitch> 5.37-1.mga6
+ Revision: 1066353
- new version 5.37

* Sun Aug 21 2016 guillomovitch <guillomovitch> 5.35-1.mga6
+ Revision: 1047601
- new version 5.35

* Thu Mar 03 2016 umeabot <umeabot> 5.31-2.mga6
+ Revision: 984150
- Rebuild for openssl

* Wed Mar 02 2016 oden <oden> 5.31-1.mga6
+ Revision: 983346
- 5.31

* Fri Dec 18 2015 oden <oden> 5.28-1.mga6
+ Revision: 911640
- 5.28
- P0: enable build against libressl
- drop old dep cruft

* Sat Jul 25 2015 sander85 <sander85> 5.20-1.mga6
+ Revision: 857344
- New version: 5.20
- French man pages were removed
- Stop using --with-threads=fork (breaks build + https://www.stunnel.org/pipermail/stunnel-users/2015-July/005170.html)
- Fix CVE-2015-3644

* Fri May 08 2015 luigiwalser <luigiwalser> 5.03-4.mga5
+ Revision: 821475
- fix PID file location in default config (mga#15881)
- disable SSLv3 in default config

* Wed Oct 15 2014 umeabot <umeabot> 5.03-3.mga5
+ Revision: 740620
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 5.03-2.mga5
+ Revision: 689564
- Mageia 5 Mass Rebuild

* Wed Aug 27 2014 pterjan <pterjan> 5.03-1.mga5
+ Revision: 668552
- 5.03

* Tue Apr 29 2014 guillomovitch <guillomovitch> 5.01-1.mga5
+ Revision: 618874
- new version 5.0.1

* Sat Mar 29 2014 luigiwalser <luigiwalser> 5.00-2.mga5
+ Revision: 609585
- create pidfile dir at package installation time

* Wed Mar 19 2014 guillomovitch <guillomovitch> 5.00-1.mga5
+ Revision: 605879
- new version 5.00

* Sat Oct 19 2013 umeabot <umeabot> 4.56-3.mga4
+ Revision: 530118
- Mageia 4 Mass Rebuild

* Fri Jul 19 2013 danf <danf> 4.56-2.mga4
+ Revision: 456234
- source man pages are now UTF-8, so don't convert them any more since
  it corrupts them
- license is actually GPLv2 or later, and don't bother including it in package

* Sun May 26 2013 blino <blino> 4.56-1.mga4
+ Revision: 428204
- 4.56

* Tue Mar 05 2013 guillomovitch <guillomovitch> 4.55-1.mga3
+ Revision: 401451
- new version

* Mon Jan 14 2013 umeabot <umeabot> 4.54-3.mga3
+ Revision: 383570
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Mon Jan 07 2013 sander85 <sander85> 4.54-2.mga3
+ Revision: 341223
- Require openssl to fix post scriptlet

* Sat Jan 05 2013 luigiwalser <luigiwalser> 4.54-1.mga3
+ Revision: 338948
- 4.54
- fix source URLs

* Mon Sep 17 2012 guillomovitch <guillomovitch> 4.53-6.mga3
+ Revision: 295579
- no need for version in obsoletes tags
- chroot to /run/stunnel in default configuration
- convert /run/stunnel to tmpfs
- minor fixes to the systemd service

* Thu Sep 06 2012 luigiwalser <luigiwalser> 4.53-5.mga3
+ Revision: 288889
- fix syntax for obsoleting old library packages

* Wed Sep 05 2012 luigiwalser <luigiwalser> 4.53-4.mga3
+ Revision: 288622
- obsolete library package

* Mon Aug 20 2012 guillomovitch <guillomovitch> 4.53-3.mga3
+ Revision: 282639
- don't bother using library and devel subpackage, as there is no defined interface, and no include file available (#4223)

* Tue Aug 14 2012 guillomovitch <guillomovitch> 4.53-2.mga3
+ Revision: 281253
- add systemd support (Bit Twister <junk_no_spam@verizon.net>)
- mark the configuration file as configuration
- readd explicit lib package dependenncy

* Tue Aug 14 2012 guillomovitch <guillomovitch> 4.53-1.mga3
+ Revision: 281247
- new version
- spec cleanup
- drop useless patches
- drop static lib package
- use rpm-helper macros to generate ssl certificate

* Sun Jan 09 2011 blino <blino> 4.34-3.mga1
+ Revision: 3737
- remove old ldconfig scriptlets
- imported package stunnel


* Mon Jan 03 2011 Oden Eriksson <oeriksson@mandriva.com> 4.34-2mdv2011.0
+ Revision: 627719
- don't force the usage of automake1.7

* Thu Oct 14 2010 Sandro Cazzaniga <kharec@mandriva.org> 4.34-1mdv2011.0
+ Revision: 585547
- update patches
- update to 4.34
- fix pacthes names in spec file
- remove -b option

* Sat May 08 2010 Sandro Cazzaniga <kharec@mandriva.org> 4.33-2mdv2010.1
+ Revision: 544098
- add a stunnel.conf file

* Sun Apr 25 2010 Sandro Cazzaniga <kharec@mandriva.org> 4.33-1mdv2010.1
+ Revision: 538739
- update to 4.33

* Wed Apr 07 2010 Funda Wang <fwang@mandriva.org> 4.31-2mdv2010.1
+ Revision: 532515
- rebuild

  + Sandro Cazzaniga <kharec@mandriva.org>
    - fix license
    - drop some patches (applied upstream for this version)
    - update to 4.31
    - fix file list

* Fri Feb 26 2010 Oden Eriksson <oeriksson@mandriva.com> 4.29-2mdv2010.1
+ Revision: 511641
- rebuilt against openssl-0.9.8m

* Thu Dec 10 2009 Frederik Himpe <fhimpe@mandriva.org> 4.29-1mdv2010.1
+ Revision: 476124
- update to new version 4.29

* Mon Nov 09 2009 Frederik Himpe <fhimpe@mandriva.org> 4.28-1mdv2010.1
+ Revision: 463687
- Update to new version 4.28

* Sun Jun 21 2009 Oden Eriksson <oeriksson@mandriva.com> 4.27-1mdv2010.0
+ Revision: 387861
- forgot to rediff the patches, duh!
- add another file...
- 4.27

* Wed Dec 17 2008 Oden Eriksson <oeriksson@mandriva.com> 4.26-2mdv2009.1
+ Revision: 315259
- rediffed fuzzy patches

* Sun Sep 21 2008 Oden Eriksson <oeriksson@mandriva.com> 4.26-1mdv2009.0
+ Revision: 286323
- 4.26 (Major bugfixes)
- rediffed P3
- drop upstream implemented patches

* Thu Sep 11 2008 Oden Eriksson <oeriksson@mandriva.com> 4.25-4mdv2009.0
+ Revision: 283757
- fix #31837 (Incorrect pid file location in sample init script)

* Tue Sep 09 2008 Oden Eriksson <oeriksson@mandriva.com> 4.25-3mdv2009.0
+ Revision: 283080
- fix #43685 (stunnel opens multiple times and killing the pid swollows the cpu)

* Tue Sep 09 2008 Oden Eriksson <oeriksson@mandriva.com> 4.25-2mdv2009.0
+ Revision: 283072
- fix deps
- sync with fedora

* Fri Sep 05 2008 Oden Eriksson <oeriksson@mandriva.com> 4.25-1mdv2009.0
+ Revision: 281121
- 4.25

* Thu Aug 07 2008 Thierry Vignaud <tv@mandriva.org> 4.24-3mdv2009.0
+ Revision: 265742
- rebuild early 2009.0 package (before pixel changes)

  + Pixel <pixel@mandriva.com>
    - do not call ldconfig in %%post/%%postun, it is now handled by filetriggers

* Mon May 19 2008 David Walluck <walluck@mandriva.org> 4.24-2mdv2009.0
+ Revision: 209191
- move stunnel.cnf out of %%doc

* Mon May 19 2008 David Walluck <walluck@mandriva.org> 4.24-1mdv2009.0
+ Revision: 209138
- add stunnel-4.24-lib64.patch
- 4.24
- rediff lib64 patch
- update mdvconf patch

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request

* Sat Nov 10 2007 David Walluck <walluck@mandriva.org> 4.21-2mdv2008.1
+ Revision: 107380
- add 4.21 sources
- call %%{make} normally
- 4.21
- new lib policy
- split out static lib
- fix eol in INSTALL.WCE
- set pkglibdir to %%{_libdir}
- bins are now installed into %%{_bindir} and not %%{_sbindir} (by default)


* Mon Feb 05 2007 Oden Eriksson <oeriksson@mandriva.com> 4.20-1mdv2007.0
+ Revision: 116207
- 4.20
- drop obsolete and unmaintained patches
- fix the soname loading in client.c
- rediffed some patches
- synced a bit with fedora

* Tue Dec 12 2006 Gwenole Beauchesne <gbeauchesne@mandriva.com> 4.15-2mdv2007.1
+ Revision: 95732
- fix build
- lib64 fixes
- fix configure script
- Import stunnel

* Thu Jun 08 2006 Per Øyvind Karlsen <pkarlsen@mandriva.com> 4.15-1mdv2007.0
- 4.15
- regenerate P0

* Sun Nov 13 2005 Oden Eriksson <oeriksson@mandriva.com> 4.11-2mdk
- rebuilt against openssl-0.9.8a

* Wed Jul 13 2005 Oden Eriksson <oeriksson@mandriva.com> 4.11-1mdk
- 4.11 (Major bugfixes)
- rediff P0, merged pidfile location into P0

* Mon Apr 25 2005 Oden Eriksson <oeriksson@mandriva.com> 4.10-1mdk
- 4.10

* Sun Apr 17 2005 Oden Eriksson <oeriksson@mandriva.com> 4.09-1mdk
- 4.09
- rediffed P0
- use the %%mkrel macro
- fix requires-on-release

* Mon Feb 28 2005 Oden Eriksson <oeriksson@mandrakesoft.com> 4.08-1mdk
- 4.08

* Mon Jan 03 2005 Oden Eriksson <oeriksson@mandrakesoft.com> 4.07-1mdk
- 4.07

* Fri Dec 31 2004 Oden Eriksson <oeriksson@mandrakesoft.com> 4.06-3mdk
- revert latest "lib64 fixes"

* Mon Dec 27 2004 Oden Eriksson <oeriksson@mandrakesoft.com> 4.06-2mdk
- added P4 as an --with distcache rpmbuild switch (disabled per default)
- make it rpmbuildupdate aware
- misc spec file fixes

* Mon Dec 27 2004 Oden Eriksson <oeriksson@mandrakesoft.com> 4.06-1mdk
- 4.06
- rediffed P0 & P1
- fix soname (P2) and do libifictions
- automake1.7
- fix default pidfile location (P3)
- enable ipv6
- misc spec file fixes

* Tue Aug 10 2004 Giuseppe Ghibò <ghibo@mandrakesoft.com> 4.05-1mdk
- Release 4.05.
- Use automake1.4.

